import axios from "axios";
import React, { useEffect, useRef } from "react";
import styled from "styled-components";
import { toast } from "react-toastify";

const FormContainer = styled.form`
  display: flex;
  align-items: flex-end;
  gap: 10px;
  flex-wrap: wrap;
  background-color: #fff;
  padding: 20px;
  box-shadow: 0px 0px 5px #ccc;
  border-radius: 5px;
`;

const InputArea = styled.div`
  display: flex;
  flex-direction: column;
`;

const Input = styled.input`
  width: 120px;
  padding: 0 10px;
  border: 1px solid #bbb;
  border-radius: 5px;
  height: 40px;
`;

const Label = styled.label``;

const Button = styled.button`
  padding: 10px;
  cursor: pointer;
  border-radius: 5px;
  border: none;
  background-color: #2c73d2;
  color: white;
  height: 42px;
`;

const Form = ({ getUsers, onEdit, setOnEdit }) => {
  const ref = useRef();

  useEffect(() => {
    if (onEdit) {
      const user = ref.current;

      user.setor.value = onEdit.setor;
      user.tipo.value = onEdit.tipo;
      user.data.value = onEdit.data;
      user.conteudo.value = onEdit.conteudo;
    }
  }, [onEdit]);

  const handleSubmit = async (e) => {
    e.preventDefault();

    const user = ref.current;

    if (
      !user.setor.value ||
      !user.tipo.value ||
      !user.data.value ||
      !user.conteudo.value 
    ) {
      return toast.warn("Preencha todos os campos!");
    }

    if (onEdit) {
      await axios
        .put("http://localhost:8800/" + onEdit.id, {
            setor: user.setor.value,
            tipo: user.tipo.value,
            data: user.data.value,
            conteudo: user.conteudo.value,
        })
        .then(({ data }) => toast.success(data))
        .catch(({ data }) => toast.error(data));
    } else {
      await axios
        .post("http://localhost:8800", {
            setor: user.setor.value,
            tipo: user.tipo.value,
            data: user.data.value,
            conteudo: user.conteudo.value,
        })
        .then(({ data }) => toast.success(data))
        .catch(({ data }) => toast.error(data));
    }

    user.setor.value = "";
    user.tipo.value = "";
    user.data.value = "";
    user.conteudo.value = "";

    setOnEdit(null);
    getUsers();
  };

  return (
    <FormContainer ref={ref} onSubmit={handleSubmit}>
      <InputArea>
        <Label>Setor</Label>
        <Input name="setor" />
      </InputArea>
      <InputArea>
        <Label>Tipo</Label>
        <Input name="tipo" />
      </InputArea>
      <InputArea>
        <Label>Data</Label>
        <Input name="data" type="date"/>
      </InputArea>
      <InputArea>
        <Label>Conteúdo</Label>
        <Input name="conteudo" />
      </InputArea>

      <Button type="submit">SALVAR</Button>
    </FormContainer>
  );
};

export default Form;